Project Creator
===============

SoCo was created in 2012 at Music Hack Day Sydney by Rahim Sonawalla

The pysonos fork was created in 2018 by Anders Melchiorsen.


Maintainers
===========

* Anders Melchiorsen


Contributors
============

(alphabetical)

* Petter Aas
* Lawrence Akka
* Murali Allada
* Joel Björkman
* Aaron Daubman
* Johan Elmerfjord
* David Harding
* Jeff Hinrichs
* Jeroen Idserda
* Hugo van Kemenade
* Stefan Kögl
* Todd Neal
* nixscripter
* Kenneth Nielsen
* Dave O'Connor
* Dennnis O'Reilly
* phut
* Dan Poirier
* Jason Ting
* Peter Toft (pwt)
* Scott G Waters

